recharge
========

This module contains indicators from mobile phone recharges or top-ups. It
harnesses information from transaction history patterns, top-up amounts,
and periodicity.

.. currentmodule:: bandicoot.recharge

.. autosummary::
   :toctree: generated/

   amount_recharges
   interevent_time_recharges
   percent_pareto_recharges
   number_of_recharges
   average_balance_recharges